package com.javapointers.spring.rest.controller;

import com.javapointers.spring.rest.model.Student;
import com.javapointers.spring.rest.model.SubjectRequest;
import com.javapointers.spring.rest.service.StudentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping(value = "/student", produces = MediaType.APPLICATION_JSON_VALUE)
public class StudentController {

    @Autowired
    private StudentService studentService;

    @RequestMapping(method = RequestMethod.GET, value = "/info/{id}")
    public ResponseEntity<Student> getStudent(@PathVariable("id") long studentId) {
        Student student = studentService.getStudent(studentId);
        if (student != null) {
            return ResponseEntity.ok(student);
        }
        return ResponseEntity.status(HttpStatus.NO_CONTENT).body(null);
    }

    @RequestMapping(method = RequestMethod.PUT, value = "/add", consumes = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Long> addStudent(@RequestBody Student student) {
        long id = studentService.addStudent(student);
        return ResponseEntity.ok(id);
    }

    @RequestMapping(method = RequestMethod.POST, value = "/set/subjects/{id}", consumes = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Student> addSubjectsToStudent(@PathVariable("id") long studentId,
                                                        @RequestParam("subjects") String subjects) {
        Student student = studentService.setSubjects(studentId, subjects.split(","));
        return ResponseEntity.ok(student);
    }

    @RequestMapping(method = RequestMethod.POST, value = "/set/subjects/year/{id}", consumes = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Student> addSubjectsAndYear(@PathVariable("id") long studentId,
                                                      @RequestParam("subjects") String subjects,
                                                      @RequestParam(required = false, name = "year", defaultValue = "0") int year) {
        Student student = studentService.setSubjectsAndYear(studentId, year, subjects.split(","));
        return ResponseEntity.ok(student);
    }

    @RequestMapping(method = RequestMethod.POST, value = "/set/subjects/", consumes = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Student> addSubjects(@RequestBody SubjectRequest subjectRequest) {
        Student student = studentService.setSubjects(subjectRequest.getStudentId(), subjectRequest.getSubjects().toArray(new String[0]));
        return ResponseEntity.ok(student);
    }

    @RequestMapping(method = RequestMethod.DELETE, value = "/delete/{id}")
    public ResponseEntity<Boolean> deleteStudent(@PathVariable("id") long studentId) {
        boolean isSuccess = studentService.deleteStudent(studentId);
        if (isSuccess) {
            return ResponseEntity.ok(isSuccess);
        }
        return ResponseEntity.badRequest().body(false);
    }
}
