package com.javapointers.spring.rest.service;

import com.javapointers.spring.rest.model.Student;
import com.javapointers.spring.rest.model.Subject;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.Month;

@Service
public class StudentService {

    public Student getStudent(long id) {
        //retrieve student from db, in this case, we hard coded it.
        Student student = new Student();
        student.setId(id);
        student.setFirstName("John");
        student.setLastName("Dell");
        student.setBirthDate(LocalDate.of(1995, Month.APRIL, 1));
        student.setYearInSchool(2);
        student.addCurrentSubjects(Subject.SCIENCE);

        return student;
    }

    public long addStudent(Student student) {
        //adds the student in database and returns the id, in our example we just mock it
        long id = 222L;
        student.setId(id);
        return id;
    }

    public Student setSubjects(long studentId, String... subjects) {
        //retrieve student
        Student student = getStudent(studentId);
        for (String subject : subjects) {
            student.addCurrentSubjects(Subject.valueOf(subject));
        }
        return student;
    }

    public Student setSubjectsAndYear(long studentId, int year, String... subjects) {
        Student student = setSubjects(studentId, subjects);
        student.setYearInSchool(year);
        return student;
    }

    public boolean deleteStudent(long studentId) {
        //delete student in db. true if success, else false. here we just mock it and just return true.
        return true;
    }
}
